@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2022 Gary Wang <wzc782970009@gmail.com>
+//
+// SPDX-License-Identifier: MIT
+
 #include "mainwindow.h"
 
 #include "playlistmanager.h"
@@ -16,6 +20,9 @@
 int main(int argc, char *argv[])
 {
     QApplication a(argc, argv);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    a.setAttribute(Qt::ApplicationAttribute::AA_UseHighDpiPixmaps);
+#endif
 
     QTranslator translator;
     QString qmDir;
