@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2022 Gary Wang <wzc782970009@gmail.com>
+//
+// SPDX-License-Identifier: MIT
+
 #include "mainwindow.h"
 
 #include "settings.h"
@@ -32,6 +36,11 @@
 #include <QProcess>
 #include <QDesktopServices>
 
+#ifdef HAVE_QTDBUS
+#include <QDBusInterface>
+#include <QDBusConnectionInterface>
+#endif // HAVE_QTDBUS
+
 MainWindow::MainWindow(QWidget *parent)
     : FramelessWindow(parent)
     , m_am(new ActionManager)
@@ -74,7 +83,7 @@ MainWindow::MainWindow(QWidget *parent)
     m_gv->fitInView(m_gv->sceneRect(), Qt::KeepAspectRatio);
 
     connect(m_graphicsView, &GraphicsView::navigatorViewRequired,
-            this, [ = ](bool required, QTransform tf){
+            this, [ = ](bool required, const QTransform & tf){
         m_gv->setTransform(GraphicsView::resetScale(tf));
         m_gv->fitInView(m_gv->sceneRect(), Qt::KeepAspectRatio);
         m_gv->setVisible(required);
@@ -88,20 +97,21 @@ MainWindow::MainWindow(QWidget *parent)
             this, &MainWindow::loadGalleryBySingleLocalFile);
 
     m_closeButton = new ToolButton(true, m_graphicsView);
-    m_closeButton->setIcon(QIcon(":/icons/window-close"));
-    m_closeButton->setIconSize(QSize(50, 50));
+    m_closeButton->setIconSize(QSize(32, 32));
+    m_closeButton->setFixedSize(QSize(50, 50));
+    m_closeButton->setIconResourcePath(":/icons/window-close.svg");
 
     connect(m_closeButton, &QAbstractButton::clicked,
             this, &MainWindow::closeWindow);
 
     m_prevButton = new ToolButton(false, m_graphicsView);
-    m_prevButton->setIcon(QIcon(":/icons/go-previous"));
     m_prevButton->setIconSize(QSize(75, 75));
+    m_prevButton->setIconResourcePath(":/icons/go-previous.svg");
     m_prevButton->setVisible(false);
     m_prevButton->setOpacity(0, false);
     m_nextButton = new ToolButton(false, m_graphicsView);
-    m_nextButton->setIcon(QIcon(":/icons/go-next"));
     m_nextButton->setIconSize(QSize(75, 75));
+    m_nextButton->setIconResourcePath(":/icons/go-next.svg");
     m_nextButton->setVisible(false);
     m_nextButton->setOpacity(0, false);
 
@@ -733,11 +743,30 @@ void MainWindow::on_actionLocateInFileManager_triggered()
     QFileInfo fileInfo(currentFileUrl.toLocalFile());
     if (!fileInfo.exists()) return;
 
+    QUrl && folderUrl = QUrl::fromLocalFile(fileInfo.absolutePath());
+
 #ifdef Q_OS_WIN
     QProcess::startDetached("explorer", QStringList() << "/select," << QDir::toNativeSeparators(fileInfo.absoluteFilePath()));
+#elif defined(Q_OS_LINUX) and defined(HAVE_QTDBUS)
+    // Use https://www.freedesktop.org/wiki/Specifications/file-manager-interface/ if possible
+    const QDBusConnectionInterface * dbusIface = QDBusConnection::sessionBus().interface();
+    if (!dbusIface || !dbusIface->isServiceRegistered(QLatin1String("org.freedesktop.FileManager1"))) {
+        QDesktopServices::openUrl(folderUrl);
+        return;
+    }
+    QDBusInterface fm1Iface(QStringLiteral("org.freedesktop.FileManager1"),
+                            QStringLiteral("/org/freedesktop/FileManager1"),
+                            QStringLiteral("org.freedesktop.FileManager1"));
+    fm1Iface.setTimeout(1000);
+    fm1Iface.callWithArgumentList(QDBus::Block, "ShowItems", {
+                                      QStringList{currentFileUrl.toString()},
+                                      QString()
+                                  });
+    if (fm1Iface.lastError().isValid()) {
+        QDesktopServices::openUrl(folderUrl);
+    }
 #else
-    // maybe use https://www.freedesktop.org/wiki/Specifications/file-manager-interface/ for linux?
-    QDesktopServices::openUrl(QUrl::fromLocalFile(fileInfo.absolutePath()));
+    QDesktopServices::openUrl(folderUrl);
 #endif // Q_OS_WIN
 }
 
