@@ -21,7 +21,7 @@
     <message>
         <location filename="../aboutdialog.cpp" line="28"/>
         <source>None of the operations in this application will alter the pictures on disk.</source>
-        <translation type="unfinished"></translation>
+        <translation>Keine der Änderungen in dieser Anwendung modifizieren die abgespeicherten Bilder.</translation>
     </message>
     <message>
         <location filename="../aboutdialog.cpp" line="29"/>
@@ -44,123 +44,128 @@
         <translation>Version: %1</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="50"/>
         <source>Copyright (c) 2020 %1</source>
-        <translation>Copyright © 2020 %1</translation>
+        <translation type="vanished">Copyright © 2020 %1</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="52"/>
+        <location filename="../aboutdialog.cpp" line="53"/>
         <source>Logo designed by %1</source>
         <translation>Logo entworfen von %1</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="54"/>
+        <location filename="../aboutdialog.cpp" line="55"/>
         <source>Built with Qt %1 (%2)</source>
         <translation>Gemacht mit Qt %1 (%2)</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="55"/>
+        <location filename="../aboutdialog.cpp" line="56"/>
         <source>Source code</source>
         <translation>Quellcode</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="65"/>
+        <location filename="../aboutdialog.cpp" line="66"/>
         <source>Contributors</source>
         <translation>Mitwirkenden</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="67"/>
+        <location filename="../aboutdialog.cpp" line="68"/>
         <source>List of contributors on GitHub</source>
         <translation>Liste der Mitwirkenden auf GitHub</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="68"/>
+        <location filename="../aboutdialog.cpp" line="69"/>
         <source>Thanks to all people who contributed to this project.</source>
         <translation>Vielen Dank an alle, die zu diesem Projekt beigetragen haben.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="72"/>
+        <location filename="../aboutdialog.cpp" line="73"/>
         <source>Translators</source>
         <translation>Übersetzer</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="73"/>
+        <location filename="../aboutdialog.cpp" line="74"/>
         <source>I would like to thank the following people who volunteered to translate this application.</source>
         <translation>Ich möchte den folgenden Personen danken, die sich freiwillig zur Übersetzung dieser Anwendung gemeldet haben.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="117"/>
+        <location filename="../aboutdialog.cpp" line="118"/>
         <source>%1 is built on the following free software libraries:</source>
         <comment>Free as in freedom</comment>
         <translation>%1 basiert auf den folgenden freien Softwarebibliotheken:</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="141"/>
+        <location filename="../aboutdialog.cpp" line="142"/>
         <source>&amp;Special Thanks</source>
         <translation>&amp;Besonderer Dank</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="143"/>
+        <location filename="../aboutdialog.cpp" line="144"/>
         <source>&amp;Third-party Libraries</source>
         <translation>&amp;Bibliotheken von Drittanbietern</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="79"/>
+        <location filename="../aboutdialog.cpp" line="80"/>
         <source>Your Rights</source>
         <translation>Ihre Rechte</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="81"/>
+        <location filename="../aboutdialog.cpp" line="50"/>
+        <source>Copyright (c) %1 %2</source>
+        <comment>%1 is year, %2 is the name of copyright holder(s)</comment>
+        <translation>Copyright (c) %1 %2</translation>
+    </message>
+    <message>
+        <location filename="../aboutdialog.cpp" line="82"/>
         <source>%1 is released under the MIT License.</source>
         <translation>%1 wird unter der MIT-Lizenz veröffentlicht.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="82"/>
+        <location filename="../aboutdialog.cpp" line="83"/>
         <source>This license grants people a number of freedoms:</source>
         <translation>Diese Lizenz gewährt Menschen eine Reihe von Freiheiten:</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="83"/>
+        <location filename="../aboutdialog.cpp" line="84"/>
         <source>You are free to use %1, for any purpose</source>
         <translation>Sie dürfen %1 für jeden Zweck verwenden</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="84"/>
+        <location filename="../aboutdialog.cpp" line="85"/>
         <source>You are free to distribute %1</source>
         <translation>Sie dürfen %1 verteilen</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="85"/>
+        <location filename="../aboutdialog.cpp" line="86"/>
         <source>You can study how %1 works and change it</source>
         <translation>Sie können untersuchen, wie %1 funktioniert, und es ändern</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="86"/>
+        <location filename="../aboutdialog.cpp" line="87"/>
         <source>You can distribute changed versions of %1</source>
         <translation>Sie können geänderte Versionen von %1 verteilen</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="88"/>
+        <location filename="../aboutdialog.cpp" line="89"/>
         <source>The MIT license guarantees you this freedom. Nobody is ever permitted to take it away.</source>
         <translation>Die MIT-Lizenz garantiert Ihnen diese Freiheit. Niemand darf es jemals wegnehmen.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="116"/>
+        <location filename="../aboutdialog.cpp" line="117"/>
         <source>Third-party Libraries used by %1</source>
         <translation>Von %1 verwendete Bibliotheken von Drittanbietern</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="139"/>
+        <location filename="../aboutdialog.cpp" line="140"/>
         <source>&amp;Help</source>
         <translation>&amp;Hilfe</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="140"/>
+        <location filename="../aboutdialog.cpp" line="141"/>
         <source>&amp;About</source>
         <translation>&amp;Über</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="142"/>
+        <location filename="../aboutdialog.cpp" line="143"/>
         <source>&amp;License</source>
         <translation>&amp;Lizenz</translation>
     </message>
@@ -168,7 +173,7 @@
 <context>
     <name>GraphicsScene</name>
     <message>
-        <location filename="../graphicsscene.cpp" line="48"/>
+        <location filename="../graphicsscene.cpp" line="57"/>
         <source>Drag image here</source>
         <translation>Ziehen Sie das Bild hierher</translation>
     </message>
@@ -176,7 +181,7 @@
 <context>
     <name>GraphicsView</name>
     <message>
-        <location filename="../graphicsview.cpp" line="329"/>
+        <location filename="../graphicsview.cpp" line="333"/>
         <source>File url list is empty</source>
         <translation>Die Datei-URL-Liste ist leer</translation>
     </message>
@@ -192,12 +197,12 @@
         <translation>Bilddaten sind ungültig oder werden derzeit nicht unterstützt</translation>
     </message>
     <message>
-        <location filename="../graphicsview.cpp" line="337"/>
+        <location filename="../graphicsview.cpp" line="341"/>
         <source>Image data is invalid</source>
         <translation>Bilddaten sind ungültig</translation>
     </message>
     <message>
-        <location filename="../graphicsview.cpp" line="344"/>
+        <location filename="../graphicsview.cpp" line="348"/>
         <source>Not supported mimedata: %1</source>
         <translation>Nicht unterstützte Mimedaten: %1</translation>
     </message>
@@ -205,96 +210,122 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="163"/>
+        <location filename="../mainwindow.cpp" line="160"/>
         <source>File url list is empty</source>
         <translation>Die Datei-URL-Liste ist leer</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="374"/>
+        <location filename="../mainwindow.cpp" line="403"/>
         <source>&amp;Copy</source>
         <translation>&amp;Kopieren</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="73"/>
+        <location filename="../actionmanager.cpp" line="83"/>
         <source>Copy P&amp;ixmap</source>
         <translation>P&amp;ixmap kopieren</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="74"/>
+        <location filename="../actionmanager.cpp" line="84"/>
         <source>Copy &amp;File Path</source>
         <translation>&amp;Dateipfad kopieren</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="80"/>
+        <location filename="../actionmanager.cpp" line="100"/>
         <source>Properties</source>
         <translation>Eigenschaften</translation>
     </message>
     <message>
         <location filename="../aboutdialog.cpp" line="35"/>
-        <location filename="../actionmanager.cpp" line="76"/>
+        <location filename="../actionmanager.cpp" line="86"/>
         <source>Stay on top</source>
         <translation>Oben bleiben</translation>
     </message>
     <message>
         <location filename="../aboutdialog.cpp" line="38"/>
-        <location filename="../actionmanager.cpp" line="77"/>
+        <location filename="../actionmanager.cpp" line="87"/>
         <source>Protected mode</source>
         <translation>Geschützter Modus</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="65"/>
+        <location filename="../actionmanager.cpp" line="72"/>
         <source>Zoom in</source>
-        <translation type="unfinished"></translation>
+        <translation>Hineinzoomen</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="66"/>
+        <location filename="../actionmanager.cpp" line="73"/>
         <source>Zoom out</source>
-        <translation type="unfinished"></translation>
+        <translation>Herauszoomen</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="70"/>
+        <location filename="../actionmanager.cpp" line="80"/>
         <source>Flip &amp;Horizontally</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Horizontal spiegeln</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="75"/>
+        <location filename="../actionmanager.cpp" line="85"/>
         <source>&amp;Paste</source>
-        <translation type="unfinished"></translation>
+        <translation>%Einfügen</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="67"/>
+        <location filename="../actionmanager.cpp" line="74"/>
         <source>Toggle Checkerboard</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../actionmanager.cpp" line="63"/>
-        <source>Actual size</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../actionmanager.cpp" line="64"/>
-        <source>Toggle maximize</source>
-        <translation type="unfinished">Maximieren umschalten</translation>
+        <translation>Schachbrettmuster umschalten</translation>
     </message>
     <message>
         <location filename="../actionmanager.cpp" line="68"/>
+        <source>&amp;Open...</source>
+        <translation>&amp;Öffnen...</translation>
+    </message>
+    <message>
+        <location filename="../actionmanager.cpp" line="70"/>
+        <source>Actual size</source>
+        <translation>Tatsächliche Größe</translation>
+    </message>
+    <message>
+        <location filename="../actionmanager.cpp" line="71"/>
+        <source>Toggle maximize</source>
+        <translation>Maximieren umschalten</translation>
+    </message>
+    <message>
+        <location filename="../actionmanager.cpp" line="75"/>
         <source>Rotate right</source>
-        <translation type="unfinished"></translation>
+        <translation>Nach rechts drehen</translation>
+    </message>
+    <message>
+        <location filename="../actionmanager.cpp" line="77"/>
+        <source>Previous image</source>
+        <translation>Vorheriges Bild</translation>
     </message>
     <message>
         <location filename="../actionmanager.cpp" line="78"/>
+        <source>Next image</source>
+        <translation>Nächstes Bild</translation>
+    </message>
+    <message>
+        <location filename="../actionmanager.cpp" line="88"/>
         <source>Configure...</source>
         <translation>Konfigurieren&#xa0;…</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="79"/>
+        <location filename="../actionmanager.cpp" line="89"/>
         <source>Help</source>
         <translation>Hilfe</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="81"/>
+        <location filename="../actionmanager.cpp" line="92"/>
+        <source>Show in File Explorer</source>
+        <comment>File Explorer is the name of explorer.exe under Windows</comment>
+        <translation>Im Dateiexplorer zeigen</translation>
+    </message>
+    <message>
+        <location filename="../actionmanager.cpp" line="98"/>
+        <source>Show in directory</source>
+        <translation>Im Verzeichnis zeigen</translation>
+    </message>
+    <message>
+        <location filename="../actionmanager.cpp" line="101"/>
         <source>Quit</source>
-        <translation type="unfinished"></translation>
+        <translation>Beenden</translation>
     </message>
 </context>
 <context>
@@ -308,304 +339,304 @@
 <context>
     <name>MetadataModel</name>
     <message>
-        <location filename="../metadatamodel.cpp" line="36"/>
+        <location filename="../metadatamodel.cpp" line="37"/>
         <source>Origin</source>
         <comment>Section name.</comment>
         <translation>Ursprung</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="37"/>
+        <location filename="../metadatamodel.cpp" line="38"/>
         <source>Image</source>
         <comment>Section name.</comment>
         <translation>Bild</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="41"/>
+        <location filename="../metadatamodel.cpp" line="42"/>
         <source>File</source>
         <comment>Section name.</comment>
         <translation>Datei</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="38"/>
+        <location filename="../metadatamodel.cpp" line="39"/>
         <source>Camera</source>
         <comment>Section name.</comment>
         <translation>Fotoapparat</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="28"/>
+        <location filename="../metadatamodel.cpp" line="29"/>
         <source>%1 File</source>
         <translation>%1-Datei</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="35"/>
+        <location filename="../metadatamodel.cpp" line="36"/>
         <source>Description</source>
         <comment>Section name.</comment>
         <translation>Beschreibung</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="39"/>
+        <location filename="../metadatamodel.cpp" line="40"/>
         <source>Advanced photo</source>
         <comment>Section name.</comment>
         <translation>Erweitertes Foto</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="40"/>
+        <location filename="../metadatamodel.cpp" line="41"/>
         <source>GPS</source>
         <comment>Section name.</comment>
         <translation>GPS</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="44"/>
+        <location filename="../metadatamodel.cpp" line="46"/>
         <source>Dimensions</source>
         <translation>Maße</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="46"/>
+        <location filename="../metadatamodel.cpp" line="48"/>
         <source>Aspect ratio</source>
         <translation>Seitenverhältnis</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="49"/>
+        <location filename="../metadatamodel.cpp" line="52"/>
         <source>Frame count</source>
-        <translation type="unfinished"></translation>
+        <translation>Framezahl</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="53"/>
+        <location filename="../metadatamodel.cpp" line="56"/>
         <source>Name</source>
         <translation>Name</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="55"/>
+        <location filename="../metadatamodel.cpp" line="58"/>
         <source>Item type</source>
         <translation>Objekttyp</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="57"/>
+        <location filename="../metadatamodel.cpp" line="60"/>
         <source>Folder path</source>
         <translation>Ordnerpfad</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="59"/>
+        <location filename="../metadatamodel.cpp" line="62"/>
         <source>Size</source>
         <translation>Größe</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="61"/>
+        <location filename="../metadatamodel.cpp" line="64"/>
         <source>Date created</source>
         <translation>Datum erstellt</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="63"/>
+        <location filename="../metadatamodel.cpp" line="66"/>
         <source>Date modified</source>
         <translation>Datum geändert</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="70"/>
+        <location filename="../metadatamodel.cpp" line="73"/>
         <source>Title</source>
-        <translation type="unfinished"></translation>
+        <translation>Titel</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="72"/>
+        <location filename="../metadatamodel.cpp" line="75"/>
         <source>Subject</source>
-        <translation type="unfinished"></translation>
+        <translation>Betreff</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="74"/>
+        <location filename="../metadatamodel.cpp" line="77"/>
         <source>Rating</source>
         <translation>Bewertung</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="76"/>
+        <location filename="../metadatamodel.cpp" line="79"/>
         <source>Tags</source>
-        <translation type="unfinished"></translation>
+        <translation>Tags</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="78"/>
+        <location filename="../metadatamodel.cpp" line="81"/>
         <source>Comments</source>
         <translation>Kommentare</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="81"/>
+        <location filename="../metadatamodel.cpp" line="84"/>
         <source>Authors</source>
         <translation>Autoren</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="83"/>
+        <location filename="../metadatamodel.cpp" line="86"/>
         <source>Date taken</source>
         <translation>Datum genommen</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="89"/>
+        <location filename="../metadatamodel.cpp" line="92"/>
         <source>Program name</source>
         <translation>Programmname</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="91"/>
+        <location filename="../metadatamodel.cpp" line="94"/>
         <source>Copyright</source>
-        <translation type="unfinished"></translation>
+        <translation>Copyright</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="94"/>
+        <location filename="../metadatamodel.cpp" line="97"/>
         <source>Horizontal resolution</source>
         <translation>Horizontale Auflösung</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="96"/>
+        <location filename="../metadatamodel.cpp" line="99"/>
         <source>Vertical resolution</source>
         <translation>Vertikale Auflösung</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="98"/>
+        <location filename="../metadatamodel.cpp" line="101"/>
         <source>Resolution unit</source>
         <translation>Auflösungseinheit</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="100"/>
+        <location filename="../metadatamodel.cpp" line="103"/>
         <source>Colour representation</source>
         <translation>Farbdarstellung</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="103"/>
+        <location filename="../metadatamodel.cpp" line="106"/>
         <source>Camera maker</source>
         <translation>Kamerahersteller</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="105"/>
+        <location filename="../metadatamodel.cpp" line="108"/>
         <source>Camera model</source>
         <translation>Kameramodell</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="107"/>
+        <location filename="../metadatamodel.cpp" line="110"/>
         <source>F-stop</source>
         <translation>Blendenzahl</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="109"/>
+        <location filename="../metadatamodel.cpp" line="112"/>
         <source>Exposure time</source>
         <translation>Belichtungszeit</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="111"/>
+        <location filename="../metadatamodel.cpp" line="114"/>
         <source>ISO speed</source>
         <translation>ISO-Geschwindigkeit</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="113"/>
+        <location filename="../metadatamodel.cpp" line="116"/>
         <source>Exposure bias</source>
         <translation>Belichtungskorrektur</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="115"/>
+        <location filename="../metadatamodel.cpp" line="118"/>
         <source>Focal length</source>
         <translation>Brennweite</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="117"/>
+        <location filename="../metadatamodel.cpp" line="120"/>
         <source>Max aperture</source>
         <translation>Maximale Blende</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="119"/>
+        <location filename="../metadatamodel.cpp" line="122"/>
         <source>Metering mode</source>
         <translation>Messmodus</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="121"/>
+        <location filename="../metadatamodel.cpp" line="124"/>
         <source>Flash mode</source>
         <translation>Flash-Modus</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="123"/>
+        <location filename="../metadatamodel.cpp" line="126"/>
         <source>35mm focal length</source>
         <translation>35&#xa0;mm Brennweite</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="126"/>
+        <location filename="../metadatamodel.cpp" line="129"/>
         <source>Lens model</source>
         <translation>Objektivmodell</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="128"/>
+        <location filename="../metadatamodel.cpp" line="131"/>
         <source>Brightness</source>
         <translation>Helligkeit</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="130"/>
+        <location filename="../metadatamodel.cpp" line="133"/>
         <source>Exposure program</source>
         <translation>Belichtungsprogramm</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="132"/>
+        <location filename="../metadatamodel.cpp" line="135"/>
         <source>Saturation</source>
         <translation>Sättigung</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="134"/>
+        <location filename="../metadatamodel.cpp" line="137"/>
         <source>Sharpness</source>
         <translation>Schärfe</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="136"/>
+        <location filename="../metadatamodel.cpp" line="139"/>
         <source>White balance</source>
         <translation>Weißabgleich</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="138"/>
+        <location filename="../metadatamodel.cpp" line="141"/>
         <source>Digital zoom</source>
         <translation>Digitaler Zoom</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="140"/>
+        <location filename="../metadatamodel.cpp" line="143"/>
         <source>EXIF version</source>
         <translation>EXIF-Version</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="143"/>
+        <location filename="../metadatamodel.cpp" line="146"/>
         <source>Latitude reference</source>
-        <translation type="unfinished"></translation>
+        <translation>Breitengradbezug</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="145"/>
+        <location filename="../metadatamodel.cpp" line="148"/>
         <source>Latitude</source>
         <translation>Breitengrad</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="147"/>
+        <location filename="../metadatamodel.cpp" line="150"/>
         <source>Longitude reference</source>
-        <translation type="unfinished"></translation>
+        <translation>Längengradbezug</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="149"/>
+        <location filename="../metadatamodel.cpp" line="152"/>
         <source>Longitude</source>
         <translation>Längengrad</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="151"/>
+        <location filename="../metadatamodel.cpp" line="154"/>
         <source>Altitude reference</source>
-        <translation type="unfinished"></translation>
+        <translation>Höhenbezug</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="153"/>
+        <location filename="../metadatamodel.cpp" line="156"/>
         <source>Altitude</source>
         <translation>Höhe</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="163"/>
+        <location filename="../metadatamodel.cpp" line="166"/>
         <source>%1 x %2</source>
         <translation>%1 × %2</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="181"/>
+        <location filename="../metadatamodel.cpp" line="184"/>
         <source>%1 : %2</source>
         <translation>%1 : %2</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="306"/>
+        <location filename="../metadatamodel.cpp" line="309"/>
         <source>Property</source>
         <translation>Eigenschaft</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="306"/>
+        <location filename="../metadatamodel.cpp" line="309"/>
         <source>Value</source>
         <translation>Wert</translation>
     </message>
@@ -613,49 +644,64 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../settingsdialog.cpp" line="16"/>
+        <location filename="../settingsdialog.cpp" line="17"/>
         <source>Settings</source>
         <translation>Einstellungen</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="21"/>
+        <location filename="../settingsdialog.cpp" line="22"/>
         <source>Do nothing</source>
         <translation>Nichts tun</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="22"/>
+        <location filename="../settingsdialog.cpp" line="23"/>
         <source>Close the window</source>
         <translation>Fenster schließen</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="23"/>
+        <location filename="../settingsdialog.cpp" line="24"/>
         <source>Toggle maximize</source>
         <translation>Maximieren umschalten</translation>
     </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="27"/>
-        <source>Zoom in and out</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../settingsdialog.cpp" line="28"/>
-        <source>View next or previous item</source>
-        <translation type="unfinished"></translation>
+        <source>Zoom in and out</source>
+        <translation>Hinein- und Hinauszoomen</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="41"/>
+        <location filename="../settingsdialog.cpp" line="29"/>
+        <source>View next or previous item</source>
+        <translation>Zeige nächstes oder vorheriges Element</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="33"/>
+        <source>Auto size</source>
+        <translation>Automatische Größe</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="34"/>
+        <source>Maximized</source>
+        <translation>Maximiert</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="52"/>
         <source>Stay on top when start-up</source>
         <translation>Beim Start oben bleiben</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="42"/>
+        <location filename="../settingsdialog.cpp" line="53"/>
         <source>Double-click behavior</source>
         <translation>Doppelklickverhalten</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="43"/>
+        <location filename="../settingsdialog.cpp" line="54"/>
         <source>Mouse wheel behavior</source>
-        <translation type="unfinished"></translation>
+        <translation>Mausradverhalten</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="55"/>
+        <source>Default window size</source>
+        <translation>Standard-Fenstergröße</translation>
     </message>
 </context>
 <context>
