@@ -44,123 +44,128 @@
         <translation>Versie: %1</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="50"/>
         <source>Copyright (c) 2020 %1</source>
-        <translation>Copyright (c) 2020 %1</translation>
+        <translation type="vanished">Copyright (c) 2020 %1</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="52"/>
+        <location filename="../aboutdialog.cpp" line="53"/>
         <source>Logo designed by %1</source>
         <translation>Logo gemaakt door %1</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="54"/>
+        <location filename="../aboutdialog.cpp" line="55"/>
         <source>Built with Qt %1 (%2)</source>
         <translation>Gebouwd met Qt %1 (%2)</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="55"/>
+        <location filename="../aboutdialog.cpp" line="56"/>
         <source>Source code</source>
         <translation>Broncode</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="65"/>
+        <location filename="../aboutdialog.cpp" line="66"/>
         <source>Contributors</source>
         <translation>Bijdragers</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="67"/>
+        <location filename="../aboutdialog.cpp" line="68"/>
         <source>List of contributors on GitHub</source>
         <translation>Lijst met bijdragers op GitHub</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="68"/>
+        <location filename="../aboutdialog.cpp" line="69"/>
         <source>Thanks to all people who contributed to this project.</source>
         <translation>Met dank aan alle personen die hebben bijgedragen aan dit project.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="72"/>
+        <location filename="../aboutdialog.cpp" line="73"/>
         <source>Translators</source>
         <translation>Vertalers</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="73"/>
+        <location filename="../aboutdialog.cpp" line="74"/>
         <source>I would like to thank the following people who volunteered to translate this application.</source>
         <translation>Ik wil graag de volgende mensen bedanken die vrijwillig hebben bijgedragen aan vertalingen.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="117"/>
+        <location filename="../aboutdialog.cpp" line="118"/>
         <source>%1 is built on the following free software libraries:</source>
         <comment>Free as in freedom</comment>
         <translation>%1 is gebouwd met de volgende vrijesoftwarebibliotheken:</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="141"/>
+        <location filename="../aboutdialog.cpp" line="142"/>
         <source>&amp;Special Thanks</source>
         <translation>&amp;Met dank aan</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="143"/>
+        <location filename="../aboutdialog.cpp" line="144"/>
         <source>&amp;Third-party Libraries</source>
         <translation>Ex&amp;terne bibliotheken</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="79"/>
+        <location filename="../aboutdialog.cpp" line="80"/>
         <source>Your Rights</source>
         <translation>Uw rechten</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="81"/>
+        <location filename="../aboutdialog.cpp" line="50"/>
+        <source>Copyright (c) %1 %2</source>
+        <comment>%1 is year, %2 is the name of copyright holder(s)</comment>
+        <translation>Copyright (c) %1 %2</translation>
+    </message>
+    <message>
+        <location filename="../aboutdialog.cpp" line="82"/>
         <source>%1 is released under the MIT License.</source>
         <translation>%1 is uitgebracht onder de MIT-licentie.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="82"/>
+        <location filename="../aboutdialog.cpp" line="83"/>
         <source>This license grants people a number of freedoms:</source>
         <translation>Deze licentie biedt een hoop vrijheden:</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="83"/>
+        <location filename="../aboutdialog.cpp" line="84"/>
         <source>You are free to use %1, for any purpose</source>
         <translation>U mag %1 gratis gebruiken, voor welk doeleinde dan ook</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="84"/>
+        <location filename="../aboutdialog.cpp" line="85"/>
         <source>You are free to distribute %1</source>
         <translation>U mag %1 vrij verspreiden</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="85"/>
+        <location filename="../aboutdialog.cpp" line="86"/>
         <source>You can study how %1 works and change it</source>
         <translation>U kunt bekijken hoe %1 werkt en aanpassingen doen</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="86"/>
+        <location filename="../aboutdialog.cpp" line="87"/>
         <source>You can distribute changed versions of %1</source>
         <translation>U mag aangepaste versie van %1 vrij verspreiden</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="88"/>
+        <location filename="../aboutdialog.cpp" line="89"/>
         <source>The MIT license guarantees you this freedom. Nobody is ever permitted to take it away.</source>
         <translation>De MIT-licentie garandeert u deze vrijheid, en niemand mag deze vrijheid wegnemen.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="116"/>
+        <location filename="../aboutdialog.cpp" line="117"/>
         <source>Third-party Libraries used by %1</source>
         <translation>Door %1 gebruikte externe bibliotheken</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="139"/>
+        <location filename="../aboutdialog.cpp" line="140"/>
         <source>&amp;Help</source>
         <translation>&amp;Hulp</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="140"/>
+        <location filename="../aboutdialog.cpp" line="141"/>
         <source>&amp;About</source>
         <translation>&amp;Over</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="142"/>
+        <location filename="../aboutdialog.cpp" line="143"/>
         <source>&amp;License</source>
         <translation>&amp;Licentie</translation>
     </message>
@@ -168,7 +173,7 @@
 <context>
     <name>GraphicsScene</name>
     <message>
-        <location filename="../graphicsscene.cpp" line="48"/>
+        <location filename="../graphicsscene.cpp" line="57"/>
         <source>Drag image here</source>
         <translation>Sleep een afbeelding hierheen</translation>
     </message>
@@ -176,7 +181,7 @@
 <context>
     <name>GraphicsView</name>
     <message>
-        <location filename="../graphicsview.cpp" line="329"/>
+        <location filename="../graphicsview.cpp" line="333"/>
         <source>File url list is empty</source>
         <translation>De bestandspadlijst is leeg</translation>
     </message>
@@ -192,12 +197,12 @@
         <translation>De afbeeldingsgegevens zijn beschadigd of worden niet ondersteund</translation>
     </message>
     <message>
-        <location filename="../graphicsview.cpp" line="337"/>
+        <location filename="../graphicsview.cpp" line="341"/>
         <source>Image data is invalid</source>
         <translation>Beschadigde afbeeldingsgegevens</translation>
     </message>
     <message>
-        <location filename="../graphicsview.cpp" line="344"/>
+        <location filename="../graphicsview.cpp" line="348"/>
         <source>Not supported mimedata: %1</source>
         <translation>Niet-ondersteunde mime-gegevens: %1</translation>
     </message>
@@ -205,94 +210,120 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="163"/>
+        <location filename="../mainwindow.cpp" line="160"/>
         <source>File url list is empty</source>
         <translation>De bestandspadlijst is leeg</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="374"/>
+        <location filename="../mainwindow.cpp" line="403"/>
         <source>&amp;Copy</source>
         <translation>&amp;Kopiëren</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="73"/>
+        <location filename="../actionmanager.cpp" line="83"/>
         <source>Copy P&amp;ixmap</source>
         <translation>P&amp;ixmap kopiëren</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="74"/>
+        <location filename="../actionmanager.cpp" line="84"/>
         <source>Copy &amp;File Path</source>
         <translation>&amp;Bestandspad kopiëren</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="80"/>
+        <location filename="../actionmanager.cpp" line="100"/>
         <source>Properties</source>
         <translation>Eigenschappen</translation>
     </message>
     <message>
         <location filename="../aboutdialog.cpp" line="35"/>
-        <location filename="../actionmanager.cpp" line="76"/>
+        <location filename="../actionmanager.cpp" line="86"/>
         <source>Stay on top</source>
         <translation>Altijd bovenop</translation>
     </message>
     <message>
         <location filename="../aboutdialog.cpp" line="38"/>
-        <location filename="../actionmanager.cpp" line="77"/>
+        <location filename="../actionmanager.cpp" line="87"/>
         <source>Protected mode</source>
         <translation>Beschermde modus</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="65"/>
+        <location filename="../actionmanager.cpp" line="72"/>
         <source>Zoom in</source>
         <translation>Inzoomen</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="66"/>
+        <location filename="../actionmanager.cpp" line="73"/>
         <source>Zoom out</source>
         <translation>Uitzoomen</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="70"/>
+        <location filename="../actionmanager.cpp" line="80"/>
         <source>Flip &amp;Horizontally</source>
         <translation>&amp;Horizontaal spiegelen</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="75"/>
+        <location filename="../actionmanager.cpp" line="85"/>
         <source>&amp;Paste</source>
         <translation>&amp;Plakken</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="67"/>
+        <location filename="../actionmanager.cpp" line="74"/>
         <source>Toggle Checkerboard</source>
         <translation>Schaakbordpatroon aan/uit</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="63"/>
+        <location filename="../actionmanager.cpp" line="68"/>
+        <source>&amp;Open...</source>
+        <translation>&amp;Openen…</translation>
+    </message>
+    <message>
+        <location filename="../actionmanager.cpp" line="70"/>
         <source>Actual size</source>
         <translation>Ware grootte</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="64"/>
+        <location filename="../actionmanager.cpp" line="71"/>
         <source>Toggle maximize</source>
         <translation>Maximaliseren aan/uit</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="68"/>
+        <location filename="../actionmanager.cpp" line="75"/>
         <source>Rotate right</source>
         <translation>Naar rechts draaien</translation>
     </message>
+    <message>
+        <location filename="../actionmanager.cpp" line="77"/>
+        <source>Previous image</source>
+        <translation>Vorige afbeelding</translation>
+    </message>
     <message>
         <location filename="../actionmanager.cpp" line="78"/>
+        <source>Next image</source>
+        <translation>Volgende afbeelding</translation>
+    </message>
+    <message>
+        <location filename="../actionmanager.cpp" line="88"/>
         <source>Configure...</source>
         <translation>Instellen...</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="79"/>
+        <location filename="../actionmanager.cpp" line="89"/>
         <source>Help</source>
         <translation>Hulp</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="81"/>
+        <location filename="../actionmanager.cpp" line="92"/>
+        <source>Show in File Explorer</source>
+        <comment>File Explorer is the name of explorer.exe under Windows</comment>
+        <translation>Tonen in bestandsbeheer</translation>
+    </message>
+    <message>
+        <location filename="../actionmanager.cpp" line="98"/>
+        <source>Show in directory</source>
+        <translation>Tonen in map</translation>
+    </message>
+    <message>
+        <location filename="../actionmanager.cpp" line="101"/>
         <source>Quit</source>
         <translation>Afsluiten</translation>
     </message>
@@ -308,304 +339,304 @@
 <context>
     <name>MetadataModel</name>
     <message>
-        <location filename="../metadatamodel.cpp" line="36"/>
+        <location filename="../metadatamodel.cpp" line="37"/>
         <source>Origin</source>
         <comment>Section name.</comment>
         <translation>Oorsprong</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="37"/>
+        <location filename="../metadatamodel.cpp" line="38"/>
         <source>Image</source>
         <comment>Section name.</comment>
         <translation>Afbeelding</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="41"/>
+        <location filename="../metadatamodel.cpp" line="42"/>
         <source>File</source>
         <comment>Section name.</comment>
         <translation>Bestand</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="38"/>
+        <location filename="../metadatamodel.cpp" line="39"/>
         <source>Camera</source>
         <comment>Section name.</comment>
         <translation>Camera</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="28"/>
+        <location filename="../metadatamodel.cpp" line="29"/>
         <source>%1 File</source>
         <translation>%1-bestand</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="35"/>
+        <location filename="../metadatamodel.cpp" line="36"/>
         <source>Description</source>
         <comment>Section name.</comment>
         <translation>Omschrijving</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="39"/>
+        <location filename="../metadatamodel.cpp" line="40"/>
         <source>Advanced photo</source>
         <comment>Section name.</comment>
         <translation>Uitgebreide foto</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="40"/>
+        <location filename="../metadatamodel.cpp" line="41"/>
         <source>GPS</source>
         <comment>Section name.</comment>
         <translation>GPS</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="44"/>
+        <location filename="../metadatamodel.cpp" line="46"/>
         <source>Dimensions</source>
         <translation>Afmetingen</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="46"/>
+        <location filename="../metadatamodel.cpp" line="48"/>
         <source>Aspect ratio</source>
         <translation>Beeldverhouding</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="49"/>
+        <location filename="../metadatamodel.cpp" line="52"/>
         <source>Frame count</source>
         <translation>Aantal frames</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="53"/>
+        <location filename="../metadatamodel.cpp" line="56"/>
         <source>Name</source>
         <translation>Naam</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="55"/>
+        <location filename="../metadatamodel.cpp" line="58"/>
         <source>Item type</source>
         <translation>Soort item</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="57"/>
+        <location filename="../metadatamodel.cpp" line="60"/>
         <source>Folder path</source>
         <translation>Bestandspad</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="59"/>
+        <location filename="../metadatamodel.cpp" line="62"/>
         <source>Size</source>
         <translation>Grootte</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="61"/>
+        <location filename="../metadatamodel.cpp" line="64"/>
         <source>Date created</source>
         <translation>Gemaakt op</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="63"/>
+        <location filename="../metadatamodel.cpp" line="66"/>
         <source>Date modified</source>
         <translation>Bewerkt op</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="70"/>
+        <location filename="../metadatamodel.cpp" line="73"/>
         <source>Title</source>
         <translation>Naam</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="72"/>
+        <location filename="../metadatamodel.cpp" line="75"/>
         <source>Subject</source>
         <translation>Onderwerp</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="74"/>
+        <location filename="../metadatamodel.cpp" line="77"/>
         <source>Rating</source>
         <translation>Waardering</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="76"/>
+        <location filename="../metadatamodel.cpp" line="79"/>
         <source>Tags</source>
         <translation>Labels</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="78"/>
+        <location filename="../metadatamodel.cpp" line="81"/>
         <source>Comments</source>
         <translation>Opmerkingen</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="81"/>
+        <location filename="../metadatamodel.cpp" line="84"/>
         <source>Authors</source>
         <translation>Makers</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="83"/>
+        <location filename="../metadatamodel.cpp" line="86"/>
         <source>Date taken</source>
         <translation>Genomen op</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="89"/>
+        <location filename="../metadatamodel.cpp" line="92"/>
         <source>Program name</source>
         <translation>Programmanaam</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="91"/>
+        <location filename="../metadatamodel.cpp" line="94"/>
         <source>Copyright</source>
         <translation>Copyright</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="94"/>
+        <location filename="../metadatamodel.cpp" line="97"/>
         <source>Horizontal resolution</source>
         <translation>Horizontale resolutie</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="96"/>
+        <location filename="../metadatamodel.cpp" line="99"/>
         <source>Vertical resolution</source>
         <translation>Verticale resolutie</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="98"/>
+        <location filename="../metadatamodel.cpp" line="101"/>
         <source>Resolution unit</source>
         <translation>Resolutie-eenheid</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="100"/>
+        <location filename="../metadatamodel.cpp" line="103"/>
         <source>Colour representation</source>
         <translation>Kleurweergave</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="103"/>
+        <location filename="../metadatamodel.cpp" line="106"/>
         <source>Camera maker</source>
         <translation>Camerafabrikant</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="105"/>
+        <location filename="../metadatamodel.cpp" line="108"/>
         <source>Camera model</source>
         <translation>Cameramodel</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="107"/>
+        <location filename="../metadatamodel.cpp" line="110"/>
         <source>F-stop</source>
         <translation>Openingsverhouding</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="109"/>
+        <location filename="../metadatamodel.cpp" line="112"/>
         <source>Exposure time</source>
         <translation>Belichtingstijd</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="111"/>
+        <location filename="../metadatamodel.cpp" line="114"/>
         <source>ISO speed</source>
         <translation>ISO-snelheid</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="113"/>
+        <location filename="../metadatamodel.cpp" line="116"/>
         <source>Exposure bias</source>
         <translation>Belichtingsvertekening</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="115"/>
+        <location filename="../metadatamodel.cpp" line="118"/>
         <source>Focal length</source>
         <translation>Focale lengte</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="117"/>
+        <location filename="../metadatamodel.cpp" line="120"/>
         <source>Max aperture</source>
         <translation>Max. opening</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="119"/>
+        <location filename="../metadatamodel.cpp" line="122"/>
         <source>Metering mode</source>
         <translation>Metermodus</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="121"/>
+        <location filename="../metadatamodel.cpp" line="124"/>
         <source>Flash mode</source>
         <translation>Flitsmodus</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="123"/>
+        <location filename="../metadatamodel.cpp" line="126"/>
         <source>35mm focal length</source>
         <translation>35mm focale lengte</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="126"/>
+        <location filename="../metadatamodel.cpp" line="129"/>
         <source>Lens model</source>
         <translation>Lensmodel</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="128"/>
+        <location filename="../metadatamodel.cpp" line="131"/>
         <source>Brightness</source>
         <translation>Helderheid</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="130"/>
+        <location filename="../metadatamodel.cpp" line="133"/>
         <source>Exposure program</source>
         <translation>Belichtingsprogramma</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="132"/>
+        <location filename="../metadatamodel.cpp" line="135"/>
         <source>Saturation</source>
         <translation>Verzadiging</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="134"/>
+        <location filename="../metadatamodel.cpp" line="137"/>
         <source>Sharpness</source>
         <translation>Scherpte</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="136"/>
+        <location filename="../metadatamodel.cpp" line="139"/>
         <source>White balance</source>
         <translation>Witbalans</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="138"/>
+        <location filename="../metadatamodel.cpp" line="141"/>
         <source>Digital zoom</source>
         <translation>Digitale zoom</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="140"/>
+        <location filename="../metadatamodel.cpp" line="143"/>
         <source>EXIF version</source>
         <translation>EXIF-versie</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="143"/>
+        <location filename="../metadatamodel.cpp" line="146"/>
         <source>Latitude reference</source>
         <translation>Breedtegraadverwijzing</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="145"/>
+        <location filename="../metadatamodel.cpp" line="148"/>
         <source>Latitude</source>
         <translation>Breedtegraad</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="147"/>
+        <location filename="../metadatamodel.cpp" line="150"/>
         <source>Longitude reference</source>
         <translation>Lengtegraadverwijzing</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="149"/>
+        <location filename="../metadatamodel.cpp" line="152"/>
         <source>Longitude</source>
         <translation>Lengtegraad</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="151"/>
+        <location filename="../metadatamodel.cpp" line="154"/>
         <source>Altitude reference</source>
         <translation>Hoogteverwijzing</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="153"/>
+        <location filename="../metadatamodel.cpp" line="156"/>
         <source>Altitude</source>
         <translation>Hoogte</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="163"/>
+        <location filename="../metadatamodel.cpp" line="166"/>
         <source>%1 x %2</source>
         <translation>%1 x %2</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="181"/>
+        <location filename="../metadatamodel.cpp" line="184"/>
         <source>%1 : %2</source>
         <translation>%1 : %2</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="306"/>
+        <location filename="../metadatamodel.cpp" line="309"/>
         <source>Property</source>
         <translation>Eigenschap</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="306"/>
+        <location filename="../metadatamodel.cpp" line="309"/>
         <source>Value</source>
         <translation>Waarde</translation>
     </message>
@@ -613,50 +644,65 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../settingsdialog.cpp" line="16"/>
+        <location filename="../settingsdialog.cpp" line="17"/>
         <source>Settings</source>
         <translation>Instellingen</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="21"/>
+        <location filename="../settingsdialog.cpp" line="22"/>
         <source>Do nothing</source>
         <translation>Niets doen</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="22"/>
+        <location filename="../settingsdialog.cpp" line="23"/>
         <source>Close the window</source>
         <translation>Venster sluiten</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="23"/>
+        <location filename="../settingsdialog.cpp" line="24"/>
         <source>Toggle maximize</source>
         <translation>Maximaliseren/Demaximaliseren</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="27"/>
+        <location filename="../settingsdialog.cpp" line="28"/>
         <source>Zoom in and out</source>
         <translation>In-/Uitzoomen</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="28"/>
+        <location filename="../settingsdialog.cpp" line="29"/>
         <source>View next or previous item</source>
         <translation>Ga naar volgende of vorige item</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="41"/>
+        <location filename="../settingsdialog.cpp" line="33"/>
+        <source>Auto size</source>
+        <translation>Automatische grootte</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="34"/>
+        <source>Maximized</source>
+        <translation>Gemaximaliseerd</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="52"/>
         <source>Stay on top when start-up</source>
         <translation>Automatisch altijd bovenop</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="42"/>
+        <location filename="../settingsdialog.cpp" line="53"/>
         <source>Double-click behavior</source>
         <translation>Dubbelklikgedrag</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="43"/>
+        <location filename="../settingsdialog.cpp" line="54"/>
         <source>Mouse wheel behavior</source>
         <translation>Scrollwielgedrag</translation>
     </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="55"/>
+        <source>Default window size</source>
+        <translation>Standaard vensterafmetingen</translation>
+    </message>
 </context>
 <context>
     <name>main</name>
