@@ -44,123 +44,128 @@
         <translation>版本: %1</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="50"/>
         <source>Copyright (c) 2020 %1</source>
-        <translation>版权所有 (c) 2020 %1</translation>
+        <translation type="vanished">版权所有 (c) 2020 %1</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="52"/>
+        <location filename="../aboutdialog.cpp" line="53"/>
         <source>Logo designed by %1</source>
         <translation>Logo 由 %1 设计</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="54"/>
+        <location filename="../aboutdialog.cpp" line="55"/>
         <source>Built with Qt %1 (%2)</source>
         <translation>使用 Qt %1 (%2) 进行构建</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="55"/>
+        <location filename="../aboutdialog.cpp" line="56"/>
         <source>Source code</source>
         <translation>源代码</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="65"/>
+        <location filename="../aboutdialog.cpp" line="66"/>
         <source>Contributors</source>
         <translation>贡献者</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="67"/>
+        <location filename="../aboutdialog.cpp" line="68"/>
         <source>List of contributors on GitHub</source>
         <translation>GitHub 上的贡献者列表</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="68"/>
+        <location filename="../aboutdialog.cpp" line="69"/>
         <source>Thanks to all people who contributed to this project.</source>
         <translation>感谢所有参与此项目的朋友。</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="72"/>
+        <location filename="../aboutdialog.cpp" line="73"/>
         <source>Translators</source>
         <translation>翻译者</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="73"/>
+        <location filename="../aboutdialog.cpp" line="74"/>
         <source>I would like to thank the following people who volunteered to translate this application.</source>
         <translation>我想要感谢下列自愿参与翻译此应用程序的朋友。</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="117"/>
+        <location filename="../aboutdialog.cpp" line="118"/>
         <source>%1 is built on the following free software libraries:</source>
         <comment>Free as in freedom</comment>
         <translation>%1 采用了下列自由软件程序库进行构建：</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="141"/>
+        <location filename="../aboutdialog.cpp" line="142"/>
         <source>&amp;Special Thanks</source>
         <translation>致谢(&amp;S)</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="143"/>
+        <location filename="../aboutdialog.cpp" line="144"/>
         <source>&amp;Third-party Libraries</source>
         <translation>第三方程序库(&amp;T)</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="79"/>
+        <location filename="../aboutdialog.cpp" line="80"/>
         <source>Your Rights</source>
         <translation>用户的权利</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="81"/>
+        <location filename="../aboutdialog.cpp" line="50"/>
+        <source>Copyright (c) %1 %2</source>
+        <comment>%1 is year, %2 is the name of copyright holder(s)</comment>
+        <translation>版权所有 © %1 %2</translation>
+    </message>
+    <message>
+        <location filename="../aboutdialog.cpp" line="82"/>
         <source>%1 is released under the MIT License.</source>
         <translation>%1 是在 MIT 许可协议下发布的。</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="82"/>
+        <location filename="../aboutdialog.cpp" line="83"/>
         <source>This license grants people a number of freedoms:</source>
         <translation>此许可证赋予人们以下自由的权利：</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="83"/>
+        <location filename="../aboutdialog.cpp" line="84"/>
         <source>You are free to use %1, for any purpose</source>
         <translation>任何人都可以为了任何目的自由地使用 %1</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="84"/>
+        <location filename="../aboutdialog.cpp" line="85"/>
         <source>You are free to distribute %1</source>
         <translation>任何人都可以自由地分发 %1</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="85"/>
+        <location filename="../aboutdialog.cpp" line="86"/>
         <source>You can study how %1 works and change it</source>
         <translation>任何人都可以自由地研究 %1 的工作原理并对其进行修改</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="86"/>
+        <location filename="../aboutdialog.cpp" line="87"/>
         <source>You can distribute changed versions of %1</source>
         <translation>任何人都可以自由地分发修改过的 %1 版本</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="88"/>
+        <location filename="../aboutdialog.cpp" line="89"/>
         <source>The MIT license guarantees you this freedom. Nobody is ever permitted to take it away.</source>
         <translation>此软件通过 MIT 许可证赋予用户上述自由，任何人无权剥夺。</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="116"/>
+        <location filename="../aboutdialog.cpp" line="117"/>
         <source>Third-party Libraries used by %1</source>
         <translation>%1 使用的第三方程序库</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="139"/>
+        <location filename="../aboutdialog.cpp" line="140"/>
         <source>&amp;Help</source>
         <translation>帮助(&amp;H)</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="140"/>
+        <location filename="../aboutdialog.cpp" line="141"/>
         <source>&amp;About</source>
         <translation>关于(&amp;A)</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="142"/>
+        <location filename="../aboutdialog.cpp" line="143"/>
         <source>&amp;License</source>
         <translation>软件许可证(&amp;L)</translation>
     </message>
@@ -168,7 +173,7 @@
 <context>
     <name>GraphicsScene</name>
     <message>
-        <location filename="../graphicsscene.cpp" line="48"/>
+        <location filename="../graphicsscene.cpp" line="57"/>
         <source>Drag image here</source>
         <translation>拖放图片至此</translation>
     </message>
@@ -176,7 +181,7 @@
 <context>
     <name>GraphicsView</name>
     <message>
-        <location filename="../graphicsview.cpp" line="329"/>
+        <location filename="../graphicsview.cpp" line="333"/>
         <source>File url list is empty</source>
         <translation>文件 URL 列表为空</translation>
     </message>
@@ -192,12 +197,12 @@
         <translation>图像数据无效或暂未支持</translation>
     </message>
     <message>
-        <location filename="../graphicsview.cpp" line="337"/>
+        <location filename="../graphicsview.cpp" line="341"/>
         <source>Image data is invalid</source>
         <translation>图片数据无效</translation>
     </message>
     <message>
-        <location filename="../graphicsview.cpp" line="344"/>
+        <location filename="../graphicsview.cpp" line="348"/>
         <source>Not supported mimedata: %1</source>
         <translation>不受支持的 MimeData 格式：%1</translation>
     </message>
@@ -205,94 +210,120 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="163"/>
+        <location filename="../mainwindow.cpp" line="160"/>
         <source>File url list is empty</source>
         <translation>文件 URL 列表为空</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="374"/>
+        <location filename="../mainwindow.cpp" line="403"/>
         <source>&amp;Copy</source>
         <translation>复制(&amp;C)</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="73"/>
+        <location filename="../actionmanager.cpp" line="83"/>
         <source>Copy P&amp;ixmap</source>
         <translation>复制位图(&amp;I)</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="74"/>
+        <location filename="../actionmanager.cpp" line="84"/>
         <source>Copy &amp;File Path</source>
         <translation>复制文件路径(&amp;F)</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="80"/>
+        <location filename="../actionmanager.cpp" line="100"/>
         <source>Properties</source>
         <translation>属性</translation>
     </message>
     <message>
         <location filename="../aboutdialog.cpp" line="35"/>
-        <location filename="../actionmanager.cpp" line="76"/>
+        <location filename="../actionmanager.cpp" line="86"/>
         <source>Stay on top</source>
         <translation>总在最前</translation>
     </message>
     <message>
         <location filename="../aboutdialog.cpp" line="38"/>
-        <location filename="../actionmanager.cpp" line="77"/>
+        <location filename="../actionmanager.cpp" line="87"/>
         <source>Protected mode</source>
         <translation>保护模式</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="65"/>
+        <location filename="../actionmanager.cpp" line="72"/>
         <source>Zoom in</source>
         <translation>放大</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="66"/>
+        <location filename="../actionmanager.cpp" line="73"/>
         <source>Zoom out</source>
         <translation>缩小</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="70"/>
+        <location filename="../actionmanager.cpp" line="80"/>
         <source>Flip &amp;Horizontally</source>
         <translation>水平翻转(&amp;H)</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="75"/>
+        <location filename="../actionmanager.cpp" line="85"/>
         <source>&amp;Paste</source>
         <translation>粘贴(&amp;P)</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="67"/>
+        <location filename="../actionmanager.cpp" line="74"/>
         <source>Toggle Checkerboard</source>
         <translation>切换棋盘格</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="63"/>
+        <location filename="../actionmanager.cpp" line="68"/>
+        <source>&amp;Open...</source>
+        <translation>打开(&amp;O)...</translation>
+    </message>
+    <message>
+        <location filename="../actionmanager.cpp" line="70"/>
         <source>Actual size</source>
         <translation>实际大小</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="64"/>
+        <location filename="../actionmanager.cpp" line="71"/>
         <source>Toggle maximize</source>
         <translation>最大化窗口</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="68"/>
+        <location filename="../actionmanager.cpp" line="75"/>
         <source>Rotate right</source>
         <translation>向右旋转</translation>
     </message>
+    <message>
+        <location filename="../actionmanager.cpp" line="77"/>
+        <source>Previous image</source>
+        <translation>上一个图像</translation>
+    </message>
     <message>
         <location filename="../actionmanager.cpp" line="78"/>
+        <source>Next image</source>
+        <translation>下一个图像</translation>
+    </message>
+    <message>
+        <location filename="../actionmanager.cpp" line="88"/>
         <source>Configure...</source>
         <translation>设置...</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="79"/>
+        <location filename="../actionmanager.cpp" line="89"/>
         <source>Help</source>
         <translation>帮助</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="81"/>
+        <location filename="../actionmanager.cpp" line="92"/>
+        <source>Show in File Explorer</source>
+        <comment>File Explorer is the name of explorer.exe under Windows</comment>
+        <translation>在文件资源管理器中显示</translation>
+    </message>
+    <message>
+        <location filename="../actionmanager.cpp" line="98"/>
+        <source>Show in directory</source>
+        <translation>在文件夹中显示</translation>
+    </message>
+    <message>
+        <location filename="../actionmanager.cpp" line="101"/>
         <source>Quit</source>
         <translation>退出</translation>
     </message>
@@ -308,304 +339,304 @@
 <context>
     <name>MetadataModel</name>
     <message>
-        <location filename="../metadatamodel.cpp" line="36"/>
+        <location filename="../metadatamodel.cpp" line="37"/>
         <source>Origin</source>
         <comment>Section name.</comment>
         <translation>来源</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="37"/>
+        <location filename="../metadatamodel.cpp" line="38"/>
         <source>Image</source>
         <comment>Section name.</comment>
         <translation>图像</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="41"/>
+        <location filename="../metadatamodel.cpp" line="42"/>
         <source>File</source>
         <comment>Section name.</comment>
         <translation>文件</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="38"/>
+        <location filename="../metadatamodel.cpp" line="39"/>
         <source>Camera</source>
         <comment>Section name.</comment>
         <translation>照相机</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="28"/>
+        <location filename="../metadatamodel.cpp" line="29"/>
         <source>%1 File</source>
         <translation>%1 文件</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="35"/>
+        <location filename="../metadatamodel.cpp" line="36"/>
         <source>Description</source>
         <comment>Section name.</comment>
         <translation>说明</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="39"/>
+        <location filename="../metadatamodel.cpp" line="40"/>
         <source>Advanced photo</source>
         <comment>Section name.</comment>
         <translation>高级照片</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="40"/>
+        <location filename="../metadatamodel.cpp" line="41"/>
         <source>GPS</source>
         <comment>Section name.</comment>
         <translation>GPS</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="44"/>
+        <location filename="../metadatamodel.cpp" line="46"/>
         <source>Dimensions</source>
         <translation>分辨率</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="46"/>
+        <location filename="../metadatamodel.cpp" line="48"/>
         <source>Aspect ratio</source>
         <translation>纵横比</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="49"/>
+        <location filename="../metadatamodel.cpp" line="52"/>
         <source>Frame count</source>
         <translation>总帧数</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="53"/>
+        <location filename="../metadatamodel.cpp" line="56"/>
         <source>Name</source>
         <translation>名称</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="55"/>
+        <location filename="../metadatamodel.cpp" line="58"/>
         <source>Item type</source>
         <translation>项目类型</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="57"/>
+        <location filename="../metadatamodel.cpp" line="60"/>
         <source>Folder path</source>
         <translation>文件夹路径</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="59"/>
+        <location filename="../metadatamodel.cpp" line="62"/>
         <source>Size</source>
         <translation>大小</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="61"/>
+        <location filename="../metadatamodel.cpp" line="64"/>
         <source>Date created</source>
         <translation>创建日期</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="63"/>
+        <location filename="../metadatamodel.cpp" line="66"/>
         <source>Date modified</source>
         <translation>修改日期</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="70"/>
+        <location filename="../metadatamodel.cpp" line="73"/>
         <source>Title</source>
         <translation>标题</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="72"/>
+        <location filename="../metadatamodel.cpp" line="75"/>
         <source>Subject</source>
         <translation>主题</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="74"/>
+        <location filename="../metadatamodel.cpp" line="77"/>
         <source>Rating</source>
         <translation>分级</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="76"/>
+        <location filename="../metadatamodel.cpp" line="79"/>
         <source>Tags</source>
         <translation>标记</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="78"/>
+        <location filename="../metadatamodel.cpp" line="81"/>
         <source>Comments</source>
         <translation>备注</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="81"/>
+        <location filename="../metadatamodel.cpp" line="84"/>
         <source>Authors</source>
         <translation>作者</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="83"/>
+        <location filename="../metadatamodel.cpp" line="86"/>
         <source>Date taken</source>
         <translation>拍摄日期</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="89"/>
+        <location filename="../metadatamodel.cpp" line="92"/>
         <source>Program name</source>
         <translation>程序名称</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="91"/>
+        <location filename="../metadatamodel.cpp" line="94"/>
         <source>Copyright</source>
         <translation>版权</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="94"/>
+        <location filename="../metadatamodel.cpp" line="97"/>
         <source>Horizontal resolution</source>
         <translation>水平分辨率</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="96"/>
+        <location filename="../metadatamodel.cpp" line="99"/>
         <source>Vertical resolution</source>
         <translation>垂直分辨率</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="98"/>
+        <location filename="../metadatamodel.cpp" line="101"/>
         <source>Resolution unit</source>
         <translation>分辨率单位</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="100"/>
+        <location filename="../metadatamodel.cpp" line="103"/>
         <source>Colour representation</source>
         <translation>颜色表示</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="103"/>
+        <location filename="../metadatamodel.cpp" line="106"/>
         <source>Camera maker</source>
         <translation>照相机制造商</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="105"/>
+        <location filename="../metadatamodel.cpp" line="108"/>
         <source>Camera model</source>
         <translation>照相机型号</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="107"/>
+        <location filename="../metadatamodel.cpp" line="110"/>
         <source>F-stop</source>
         <translation>光圈值</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="109"/>
+        <location filename="../metadatamodel.cpp" line="112"/>
         <source>Exposure time</source>
         <translation>曝光时间</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="111"/>
+        <location filename="../metadatamodel.cpp" line="114"/>
         <source>ISO speed</source>
         <translation>ISO 感光度</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="113"/>
+        <location filename="../metadatamodel.cpp" line="116"/>
         <source>Exposure bias</source>
         <translation>曝光补偿</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="115"/>
+        <location filename="../metadatamodel.cpp" line="118"/>
         <source>Focal length</source>
         <translation>焦距</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="117"/>
+        <location filename="../metadatamodel.cpp" line="120"/>
         <source>Max aperture</source>
         <translation>镜头最大光圈</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="119"/>
+        <location filename="../metadatamodel.cpp" line="122"/>
         <source>Metering mode</source>
         <translation>测光模式</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="121"/>
+        <location filename="../metadatamodel.cpp" line="124"/>
         <source>Flash mode</source>
         <translation>闪光灯模式</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="123"/>
+        <location filename="../metadatamodel.cpp" line="126"/>
         <source>35mm focal length</source>
         <translation>换算至 35mm 焦距</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="126"/>
+        <location filename="../metadatamodel.cpp" line="129"/>
         <source>Lens model</source>
         <translation>镜头型号</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="128"/>
+        <location filename="../metadatamodel.cpp" line="131"/>
         <source>Brightness</source>
         <translation>亮度</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="130"/>
+        <location filename="../metadatamodel.cpp" line="133"/>
         <source>Exposure program</source>
         <translation>曝光程序</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="132"/>
+        <location filename="../metadatamodel.cpp" line="135"/>
         <source>Saturation</source>
         <translation>饱和度</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="134"/>
+        <location filename="../metadatamodel.cpp" line="137"/>
         <source>Sharpness</source>
         <translation>清晰度</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="136"/>
+        <location filename="../metadatamodel.cpp" line="139"/>
         <source>White balance</source>
         <translation>白平衡</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="138"/>
+        <location filename="../metadatamodel.cpp" line="141"/>
         <source>Digital zoom</source>
         <translation>数字缩放</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="140"/>
+        <location filename="../metadatamodel.cpp" line="143"/>
         <source>EXIF version</source>
         <translation>EXIF 版本</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="143"/>
+        <location filename="../metadatamodel.cpp" line="146"/>
         <source>Latitude reference</source>
         <translation>纬度基准</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="145"/>
+        <location filename="../metadatamodel.cpp" line="148"/>
         <source>Latitude</source>
         <translation>纬度</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="147"/>
+        <location filename="../metadatamodel.cpp" line="150"/>
         <source>Longitude reference</source>
         <translation>经度基准</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="149"/>
+        <location filename="../metadatamodel.cpp" line="152"/>
         <source>Longitude</source>
         <translation>经度</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="151"/>
+        <location filename="../metadatamodel.cpp" line="154"/>
         <source>Altitude reference</source>
         <translation>海拔基准</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="153"/>
+        <location filename="../metadatamodel.cpp" line="156"/>
         <source>Altitude</source>
         <translation>海拔</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="163"/>
+        <location filename="../metadatamodel.cpp" line="166"/>
         <source>%1 x %2</source>
         <translation>%1 x %2</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="181"/>
+        <location filename="../metadatamodel.cpp" line="184"/>
         <source>%1 : %2</source>
         <translation>%1 : %2</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="306"/>
+        <location filename="../metadatamodel.cpp" line="309"/>
         <source>Property</source>
         <translation>属性</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="306"/>
+        <location filename="../metadatamodel.cpp" line="309"/>
         <source>Value</source>
         <translation>值</translation>
     </message>
@@ -613,50 +644,65 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../settingsdialog.cpp" line="16"/>
+        <location filename="../settingsdialog.cpp" line="17"/>
         <source>Settings</source>
         <translation>设定</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="21"/>
+        <location filename="../settingsdialog.cpp" line="22"/>
         <source>Do nothing</source>
         <translation>什么也不做</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="22"/>
+        <location filename="../settingsdialog.cpp" line="23"/>
         <source>Close the window</source>
         <translation>关闭窗口</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="23"/>
+        <location filename="../settingsdialog.cpp" line="24"/>
         <source>Toggle maximize</source>
         <translation>最大化窗口</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="27"/>
+        <location filename="../settingsdialog.cpp" line="28"/>
         <source>Zoom in and out</source>
         <translation>放大和缩小</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="28"/>
+        <location filename="../settingsdialog.cpp" line="29"/>
         <source>View next or previous item</source>
         <translation>查看下一项或上一项</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="41"/>
+        <location filename="../settingsdialog.cpp" line="33"/>
+        <source>Auto size</source>
+        <translation>自动大小</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="34"/>
+        <source>Maximized</source>
+        <translation>最大化</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="52"/>
         <source>Stay on top when start-up</source>
         <translation>启动时保持窗口总在最前</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="42"/>
+        <location filename="../settingsdialog.cpp" line="53"/>
         <source>Double-click behavior</source>
         <translation>双击时的行为</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="43"/>
+        <location filename="../settingsdialog.cpp" line="54"/>
         <source>Mouse wheel behavior</source>
         <translation>鼠标滚轮行为</translation>
     </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="55"/>
+        <source>Default window size</source>
+        <translation>默认窗口大小</translation>
+    </message>
 </context>
 <context>
     <name>main</name>
